
#ifndef DOCUMENTS_EXPORT_H
#define DOCUMENTS_EXPORT_H

#ifdef DOCUMENTS_STATIC_DEFINE
#  define DOCUMENTS_EXPORT
#  define DOCUMENTS_NO_EXPORT
#else
#  ifndef DOCUMENTS_EXPORT
#    ifdef MauiKitDocuments4_EXPORTS
        /* We are building this library */
#      define DOCUMENTS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define DOCUMENTS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef DOCUMENTS_NO_EXPORT
#    define DOCUMENTS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef DOCUMENTS_DEPRECATED
#  define DOCUMENTS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef DOCUMENTS_DEPRECATED_EXPORT
#  define DOCUMENTS_DEPRECATED_EXPORT DOCUMENTS_EXPORT DOCUMENTS_DEPRECATED
#endif

#ifndef DOCUMENTS_DEPRECATED_NO_EXPORT
#  define DOCUMENTS_DEPRECATED_NO_EXPORT DOCUMENTS_NO_EXPORT DOCUMENTS_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef DOCUMENTS_NO_DEPRECATED
#    define DOCUMENTS_NO_DEPRECATED
#  endif
#endif

#endif /* DOCUMENTS_EXPORT_H */
