// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef Documents_VERSION_H
#define Documents_VERSION_H

#define Documents_VERSION_STRING "4.0.2"
#define Documents_VERSION_MAJOR 4
#define Documents_VERSION_MINOR 0
#define Documents_VERSION_PATCH 2
#define Documents_VERSION ((4<<16)|(0<<8)|(2))

#endif
